from distutils.core import setup
setup(
  name='Ancalagon',
  packages=['Ancalagon'],
  version='0.0.1a',
  license='lgpl-3.0',
  description='ASGI Web framework',
  author='Nimond',
  author_email='dndnomin@gmail.com',
  url='https://github.com/Nimond/Ancalagon',
  download_url='https://github.com/Nimond/Ancalagon/archive/0.0.1a.tar.gz',
  keywords=['ASGI', 'WEB', 'FRAMEWORK', 'BLACK'],
  install_requires=[],
  classifiers=[
    'Development Status :: 3 - Alpha',
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: GNU Lesser General Public License v3 (LGPLv3)',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
  ],
)
